@@ -4,7 +4,7 @@ mod mbt {
     use serde::de::DeserializeOwned;
     use serde::{Deserialize, Serialize};
     use serde_json::Error;
-    use std::convert::TryFrom;
+    use std::convert::{TryFrom, TryInto};
     use std::str::FromStr;
     use std::time::Duration;
     use tendermint::validator::Set;
@@ -19,6 +19,7 @@ mod mbt {
         apalache::*, jsonatr::*, light_block::TmLightBlock, validator::generate_validators,
         Command, Generator, LightBlock as TestgenLightBlock, TestEnv, Tester, Validator, Vote,
     };
+    use time::OffsetDateTime;
 
     fn testgen_to_lb(tm_lb: TmLightBlock) -> LightBlock {
         LightBlock {
@@ -125,8 +126,8 @@ mod mbt {
     impl SingleStepTestFuzzer for HeaderVersionFuzzer {
         // TODO: rehash the header and re-compute commit with it
         // TODO: Unlike in tendermint-go, we don't assert for a particular version in rust
-        // TODO: Either add this check in verification or remove this test because otherwise there's no
-        // point of it
+        // TODO: Either add this check in verification or remove this test because otherwise there's
+        // no point of it
         fn fuzz_input(input: &mut BlockVerdict) -> (String, LiteVerdict) {
             let mut rng = rand::thread_rng();
 
@@ -179,13 +180,15 @@ mod mbt {
     impl SingleStepTestFuzzer for HeaderTimeFuzzer {
         fn fuzz_input(input: &mut BlockVerdict) -> (String, LiteVerdict) {
             let mut rng = rand::thread_rng();
-            let secs = tendermint::Time::now()
+            let now: Time = OffsetDateTime::now_utc().try_into().unwrap();
+            let secs = now
                 .duration_since(tendermint::Time::unix_epoch())
                 .unwrap()
                 .as_secs();
             let rand_secs = rng.gen_range(1, secs);
-            input.block.signed_header.header.time =
-                tendermint::Time::unix_epoch() + std::time::Duration::from_secs(rand_secs);
+            input.block.signed_header.header.time = (tendermint::Time::unix_epoch()
+                + std::time::Duration::from_secs(rand_secs))
+            .unwrap();
             // TODO: the fuzzing below fails with one of:
             //   - 'overflow when adding duration to instant', src/libstd/time.rs:549:31
             //   - 'No such local time',
